#include "definitions.h"                // SYS function prototypes
#include "lcd.h"
#include "tftfont.h"  	 
#include "config/default/peripheral/systick/../systick/plib_systick.h"
#include "Image.h"


#define TAIPEI_ESS_MONTH    0x11
#define TAIPEI_ESS_DATE     0x13

u16 BACK_COLOR = GREEN, POINT_COLOR = RED;      //背景色，畫筆色

void LCD_Writ_Bus(char dat)                     //SPI 數據寫入
{
    SERCOM5_SPI_Write((void*) &dat, 1);          // Set @6Mhz_SPI for ATSAME51 Family
}

void LCD_WR_DATA8(char da)                      //發送數據-8-bit 參數
{
    TFT_CS_Clear();
    TFT_A0_Set();
    LCD_Writ_Bus(da);
    TFT_CS_Set();
}

void LCD_WR_DATA(int da)                        //發送數據-16-bit 參數
{
    TFT_CS_Clear();
    TFT_A0_Set();                               // Set data as general data
    LCD_Writ_Bus(da >> 8);
    LCD_Writ_Bus(da);
    TFT_CS_Set();
}

void LCD_WR_REG(char da) 
{
    TFT_CS_Clear();
    TFT_A0_Clear();                             // Set data as Command 
    LCD_Writ_Bus(da);
    TFT_CS_Set();
}

void LCD_WR_REG_DATA(int reg, int da) {
    TFT_CS_Clear();
    LCD_WR_REG(reg);
    LCD_WR_DATA(da);
    TFT_CS_Set();
}

void Address_set(unsigned int x1, unsigned int y1, unsigned int x2, unsigned int y2) {
    LCD_WR_REG(0x2a);
    LCD_WR_DATA8(0x00);
    LCD_WR_DATA8(x1 + 2);
    LCD_WR_DATA8(00);
    LCD_WR_DATA8(x2 + 2);

    LCD_WR_REG(0x2b);
    LCD_WR_DATA8(00);
    LCD_WR_DATA8(y1 + 1);
    LCD_WR_DATA8(00);
    LCD_WR_DATA8(y2 + 1);

    LCD_WR_REG(0x2C);
}

void Lcd_Init(void) {

    TFT_CS_Clear();
    TFT_RST_Clear();
    SYSTICK_DelayMs(20);
    TFT_RST_Set();
    SYSTICK_DelayMs(20);

    //************* Start Initial Sequence **********// 
    LCD_WR_REG(0xB1);
    LCD_WR_DATA8(0x01);
    LCD_WR_DATA8(0x2C);
    LCD_WR_DATA8(0x2D);

    LCD_WR_REG(0xB2);
    LCD_WR_DATA8(0x01);
    LCD_WR_DATA8(0x2C);
    LCD_WR_DATA8(0x2D);

    LCD_WR_REG(0xB3);
    LCD_WR_DATA8(0x01);
    LCD_WR_DATA8(0x2C);
    LCD_WR_DATA8(0x2D);
    LCD_WR_DATA8(0x01);
    LCD_WR_DATA8(0x2C);
    LCD_WR_DATA8(0x2D);

    LCD_WR_REG(0xB4); //Column inversion 
    LCD_WR_DATA8(0x07);

    //ST7735R Power Sequence
    LCD_WR_REG(0xC0);
    LCD_WR_DATA8(0xA2);
    LCD_WR_DATA8(0x02);
    LCD_WR_DATA8(0x84);
    LCD_WR_REG(0xC1);
    LCD_WR_DATA8(0xC5);

    LCD_WR_REG(0xC2);
    LCD_WR_DATA8(0x0A);
    LCD_WR_DATA8(0x00);

    LCD_WR_REG(0xC3);
    LCD_WR_DATA8(0x8A);
    LCD_WR_DATA8(0x2A);
    LCD_WR_REG(0xC4);
    LCD_WR_DATA8(0x8A);
    LCD_WR_DATA8(0xEE);

    LCD_WR_REG(0xC5); //VCOM 
    LCD_WR_DATA8(0x0E);

    LCD_WR_REG(0x36); //MX, MY, RGB mode 
    LCD_WR_DATA8(0xc0);

    LCD_WR_REG(0x3A);
    LCD_WR_DATA8(0x55);

    LCD_WR_REG(0xB1);
    LCD_WR_DATA8(0x00);
    LCD_WR_DATA8(0x18);

    LCD_WR_REG(0xB6); // Display Function Control 
    LCD_WR_DATA8(0x0A);
    LCD_WR_DATA8(0xA2);



    LCD_WR_REG(0xF2); // 3Gamma Function Disable 
    LCD_WR_DATA8(0x00);

    LCD_WR_REG(0x26); //Gamma curve selected 
    LCD_WR_DATA8(0x01);

    LCD_WR_REG(0xE0); //Set Gamma 
    LCD_WR_DATA8(0x0F);
    LCD_WR_DATA8(0x20);
    LCD_WR_DATA8(0x1E);
    LCD_WR_DATA8(0x09);
    LCD_WR_DATA8(0x12);
    LCD_WR_DATA8(0x0B);
    LCD_WR_DATA8(0x50);
    LCD_WR_DATA8(0XBA);
    LCD_WR_DATA8(0x44);
    LCD_WR_DATA8(0x09);
    LCD_WR_DATA8(0x14);
    LCD_WR_DATA8(0x05);
    LCD_WR_DATA8(0x23);
    LCD_WR_DATA8(0x21);
    LCD_WR_DATA8(0x00);

    LCD_WR_REG(0XE1); //Set Gamma 
    LCD_WR_DATA8(0x00);
    LCD_WR_DATA8(0x19);
    LCD_WR_DATA8(0x19);
    LCD_WR_DATA8(0x00);
    LCD_WR_DATA8(0x12);
    LCD_WR_DATA8(0x07);
    LCD_WR_DATA8(0x2D);
    LCD_WR_DATA8(0x28);
    LCD_WR_DATA8(0x3F);
    LCD_WR_DATA8(0x02);
    LCD_WR_DATA8(0x0A);
    LCD_WR_DATA8(0x08);
    LCD_WR_DATA8(0x25);
    LCD_WR_DATA8(0x2D);
    LCD_WR_DATA8(0x0F);

    LCD_WR_REG(0x11); //Exit Sleep 
    SYSTICK_DelayMs(120);
    LCD_WR_REG(0x29); //Display on 

}

//清屏函數
//Color = 要清屏的填充色

void LCD_Clear(u16 Color) {
    u16 i, j;
    Address_set(0, 0, LCD_W - 1, LCD_H - 1);
    for (i = 0; i < LCD_W; i++) {
        for (j = 0; j < LCD_H; j++) {
            LCD_WR_DATA(Color);
        }

    }
}



//在指定位置顯示一個漢字(32*33大小)
void showhanzi32(unsigned int x, unsigned int y, unsigned char index) {
    unsigned char i, j;
    unsigned char *temp = hanzi;
    Address_set(x, y, x + 31, y + 31);          //設置區域      
    temp += index * 128;
    for (j = 0; j < 128; j++) {
        for (i = 0; i < 8; i++) {
            if ((*temp & (1 << i)) != 0) {
                LCD_WR_DATA(POINT_COLOR);
            } else {
                LCD_WR_DATA(BACK_COLOR);
            }
        }
        temp++;
    }
}

//在指定位置顯示一個漢字(16*16大小)
void showhanzi16(unsigned int x, unsigned int y, unsigned char index) {
    unsigned char i, j;
    unsigned char *temp = hanzi16;
    Address_set(x, y, x + 15, y + 15);      //設置區域     
    temp += index * 32;
    for (j = 0; j < 32; j++) {
        for (i = 0; i < 8; i++) {
            if ((*temp & (1 << i)) != 0) {
                LCD_WR_DATA(POINT_COLOR);
            } else {
                LCD_WR_DATA(BACK_COLOR);
            }
        }
        temp++;
    }
}

//畫點
//POINT_COLOR:此點的顏色
void LCD_DrawPoint(u16 x, u16 y) {
    Address_set(x, y, x, y);        //設置光標位置
    LCD_WR_DATA(POINT_COLOR);
}

//畫一個大點
//POINT_COLOR:此點的顏色
void LCD_DrawPoint_big(u16 x, u16 y) {
    LCD_Fill(x - 1, y - 1, x + 1, y + 1, POINT_COLOR);
}

//在指定區域內填充指定顏色
//區域大小:
//  (xend-xsta)*(yend-ysta)
void LCD_Fill(u16 xsta, u16 ysta, u16 xend, u16 yend, u16 color) {
    u16 i, j;
    Address_set(xsta, ysta, xend, yend);                    //設置光標位置
    for (i = ysta; i <= yend; i++) {
        for (j = xsta; j <= xend; j++)LCD_WR_DATA(color);       
    }
}

//畫線
//x1,y1:起點坐標
//x2,y2:終點坐標  
void LCD_DrawLine(u16 x1, u16 y1, u16 x2, u16 y2) {
    u16 t;
    int xerr = 0, yerr = 0, delta_x, delta_y, distance;
    int incx, incy, uRow, uCol;

    delta_x = x2 - x1;              //計算坐標增量
    delta_y = y2 - y1;
    uRow = x1;
    uCol = y1;
    if (delta_x > 0)incx = 1;       //設置單步方向
    else if (delta_x == 0)incx = 0; //垂直線
    else {
        incx = -1;
        delta_x = -delta_x;
    }
    if (delta_y > 0)incy = 1;
    else if (delta_y == 0)incy = 0; //水平線 
    else {
        incy = -1;
        delta_y = -delta_y;
    }
    if (delta_x > delta_y)distance = delta_x;   //選取基本增量坐標軸
    else distance = delta_y;
    for (t = 0; t <= distance + 1; t++)         //開始畫線輸出
    {
        LCD_DrawPoint(uRow, uCol);              //開始點出每一個點 
        xerr += delta_x;
        yerr += delta_y;
        if (xerr > distance) {
            xerr -= distance;
            uRow += incx;
        }
        if (yerr > distance) {
            yerr -= distance;
            uCol += incy;
        }
    }
}

//畫矩形
void LCD_DrawRectangle(u16 x1, u16 y1, u16 x2, u16 y2) {
    LCD_DrawLine(x1, y1, x2, y1);
    LCD_DrawLine(x1, y1, x1, y2);
    LCD_DrawLine(x1, y2, x2, y2);
    LCD_DrawLine(x2, y1, x2, y2);
}

//在指定位置畫一個指定大小的圓
//(x,y):中心點
//r    :半徑
void Draw_Circle(u16 x0, u16 y0, u8 r) {
    int a, b;
    int di;
    a = 0;
    b = r;
    di = 3 - (r << 1);                      //判斷下個點位置的標誌
    while (a <= b) {
        LCD_DrawPoint(x0 - b, y0 - a); //3           
        LCD_DrawPoint(x0 + b, y0 - a); //0           
        LCD_DrawPoint(x0 - a, y0 + b); //1       
        LCD_DrawPoint(x0 - b, y0 - a); //7           
        LCD_DrawPoint(x0 - a, y0 - b); //2             
        LCD_DrawPoint(x0 + b, y0 + a); //4               
        LCD_DrawPoint(x0 + a, y0 - b); //5
        LCD_DrawPoint(x0 + a, y0 + b); //6 
        LCD_DrawPoint(x0 - b, y0 + a);
        a++;
        // ------------------------------------------
        //  使用Bresenham算法畫圓    
        // ------------------------------------------
        if (di < 0)di += 4 * a + 6;
        else {
            di += 10 + 4 * (a - b);
            b--;
        }
        LCD_DrawPoint(x0 + a, y0 + b);
    }
}

//在指定位置顯示一個字符
//num:要顯示的字符:" "--->"~"
//mode:疊加方式(1)還是非疊加方式(0)
//在指定位置顯示一個字符
//num:要顯示的字符:" "--->"~"
//mode:疊加方式(1)還是非疊加方式(0)

void LCD_ShowChar(u16 x, u16 y, u8 num, u8 mode) {
    u8 temp;
    u8 pos, t;
    u16 x0 = x;
    u16 colortemp = POINT_COLOR;
    if (x > LCD_W - 16 || y > LCD_H - 16)return;
    //設置窗口		   
    num = num - ' '; //得到偏移後的值
    Address_set(x, y, x + 8 - 1, y + 16 - 1); //設置光標位置 
    if (!mode) //非疊加方式
    {

        for (pos = 0; pos < 16; pos++) {
            temp = asc2_1608[(u16) (num << 4) + pos]; //調用1608字體
            for (t = 0; t < 8; t++) {
                if (temp & 0x01)POINT_COLOR = colortemp;
                else POINT_COLOR = BACK_COLOR;
                LCD_WR_DATA(POINT_COLOR);
                temp >>= 1;
                x++;
            }
            x = x0;
            y++;
        }
    } else                                                      //疊加方式
    {
        for (pos = 0; pos < 16; pos++) {
            temp = asc2_1608[(u16) (num << 4) + pos];           //調用1608字體
            for (t = 0; t < 8; t++) {
                if (temp & 0x01)LCD_DrawPoint(x + t, y + pos);  //畫一個點    
                temp >>= 1;
            }
        }
    }
    POINT_COLOR = colortemp;
}

//m^n函數
u32 mypow(u8 m, u8 n) {
    u32 result = 1;
    while (n--)result *= m;
    return result;
}

//顯示2個數字
//x,y :起點坐標	 
//len :數字的位數
//color:顏色
//num:數值(0~4294967295);	
void LCD_ShowNum(u16 x, u16 y, u32 num, u8 len) {
    u8 t, temp;
    u8 enshow = 0;
    num = (u16) num;
    for (t = 0; t < len; t++) {
        temp = (num / mypow(10, len - t - 1)) % 10;
        if (enshow == 0 && t < (len - 1)) {
            if (temp == 0) {
                LCD_ShowChar(x + 8 * t, y, ' ', 0);
                continue;
            } else enshow = 1;

        }
        LCD_ShowChar(x + 8 * t, y, temp + 48, 0);
    }
}

//顯示2個數字
//x,y:起點坐標
//num:數值(0~99);		 
void LCD_Show2Num(u16 x, u16 y, u16 num, u8 len) {
    u8 t, temp;
    for (t = 0; t < len; t++) {
        temp = (num / mypow(10, len - t - 1)) % 10;
        LCD_ShowChar(x + 8 * t, y, temp + '0', 0);
    }
}

//顯示字符串
//x,y:起點坐標  
//*p:字符串起始地址
//用16字體
void LCD_ShowString(u16 x, u16 y, u8 *p) {
    while (*p != '\0') {
        if (x > LCD_W - 16) {
            x = 0;
            y += 16;
        }
        if (y > LCD_H - 16) {
            y = x = 0;
            LCD_Clear(RED);
        }
        LCD_ShowChar(x, y, *p, 0);
        x += 8;
        p++;
    }
}
extern unsigned char mon, dat;
extern uint8_t lcd_idle_flag;

// ----------------------------------------------------------------------------
// TFT LCD SHOW 圖形的副程式
// 使用 p_idx 參數來指定要秀圖的圖資編號
// ----------------------------------------------------------------------------
void showimage(unsigned char clr, unsigned int x1, unsigned int y1, unsigned int x2, unsigned int y2, const unsigned char p_idx) {
   int i, j;
   const unsigned char *p;

 p = ((FLASH_BYTE *) ((IMAGE_FLASH *) (void *) &Spider1_128x160)->address);
 
//    switch (p_idx) 
//    {
//
//    }
 
    p += 6; //offset for Bitmap header
 
    if (clr)
        LCD_Clear(WHITE);                           //清除螢幕
    Address_set(x1, y1, x1 + x2 - 1, y1 + y2 - 1);  //坐標設置
    for (i = 0; i < x2 * y2; i++) {
        j = i << 1;
        LCD_WR_DATA8(*(p + j + 1));
        LCD_WR_DATA8(*(p + j));
    }
}









































