#ifndef __OLED_H
#define __OLED_H			  	 

#define LCD_W 128
#define LCD_H 160
typedef	unsigned char u8  ;
typedef	unsigned int  u16 ;
typedef	unsigned long u32 ;

// TFT LCD 模式設置
//0:4線串行模式
//1:並行8080模式
#define OLED_MODE 0
#define SIZE 16
#define XLevelL		0x00
#define XLevelH		0x10
#define Max_Column	128
#define Max_Row		64
#define	Brightness	0xFF 
#define X_WIDTH 	128
#define Y_WIDTH 	64	    						  

#define TFT_CMD  0	//寫命令
#define TFT_DATA 1	//寫數據


typedef const unsigned char FLASH_BYTE;

typedef enum {
    FLASH = 0x0000, // internal flash
    EXTERNAL = 0x0001, // external memory
    FLASH_JPEG = 0x0002, // internal flash
    EXTERNAL_JPEG = 0x0003, // external memory
    RAM = 0x0004, // RAM 
    EDS_EPMP = 0x0005, // memory in EPMP, base addresses are 
    // are set in the hardware profile

    IMAGE_MBITMAP = 0x0000, // data resource is type Microchip bitmap
    IMAGE_JPEG = 0x0100, // data resource is type JPEG

    COMP_NONE = 0x0000, // no compression  
    COMP_RLE = 0x1000, // compressed with RLE
    COMP_IPU = 0x2000, // compressed with DEFLATE (for IPU)
} GFX_RESOURCE;

typedef struct {
    GFX_RESOURCE type; // must be FLASH
    FLASH_BYTE *address; // image address in FLASH
} IMAGE_FLASH;

extern u16 BACK_COLOR, POINT_COLOR;         //背景色，畫筆色

void Lcd_Init(void);
void LCD_Clear(u16 Color);
void Address_set(unsigned int x1, unsigned int y1, unsigned int x2, unsigned int y2);
void LCD_WR_DATA8(char da);             //發送數據-8-BIT 參數
void LCD_WR_DATA(int da);
void LCD_WR_REG(char da);

void LCD_DrawPoint(u16 x, u16 y);                       //畫點
void LCD_DrawPoint_big(u16 x, u16 y);                   //畫一個大點
u16 LCD_ReadPoint(u16 x, u16 y);                        //讀點
void Draw_Circle(u16 x0, u16 y0, u8 r);
void LCD_DrawLine(u16 x1, u16 y1, u16 x2, u16 y2);
void LCD_DrawRectangle(u16 x1, u16 y1, u16 x2, u16 y2);
void LCD_Fill(u16 xsta, u16 ysta, u16 xend, u16 yend, u16 color);
void LCD_ShowChar(u16 x, u16 y, u8 num, u8 mode);       //顯示一個字符
void LCD_ShowNum(u16 x, u16 y, u32 num, u8 len);        //顯示數字
void LCD_Show2Num(u16 x, u16 y, u16 num, u8 len);       //顯示2個數字
void LCD_ShowString(u16 x, u16 y, u8 *p);                 //顯示一個字串,1608字體

void showhanzi32(unsigned int x, unsigned int y, unsigned char index);

void showhanzi16(unsigned int x, unsigned int y, unsigned char index);

void showhanzi48(unsigned int x, unsigned int y, unsigned char index);

void showimage(unsigned char clr, unsigned int x1, unsigned int y1, unsigned int x2, unsigned int y2, const unsigned char p_idx);

void showLcdTime(u8 year, u8 mon, u8 dat, u8 hr, u8 min, u8 weekday);

//常用畫筆顏色
#define WHITE         	 0xFFFF
#define BLACK         	 0x0000	  
#define BLUE         	 0x001F  
#define BRED             0XF81F
#define GRED 			 0XFFE0
#define GBLUE			 0X07FF
#define RED           	 0xF800
#define MAGENTA       	 0xF81F
#define GREEN         	 0x07E0
#define CYAN          	 0x7FFF
#define YELLOW        	 0xFFE0
#define BROWN 			 0XBC40 //棕色
#define BRRED 			 0XFC07 //棕紅色
#define GRAY  			 0X8430 //灰色
//GUI顏色

#define DARKBLUE      	 0X01CF	//深藍色
#define LIGHTBLUE      	 0X7D7C	//淺藍色  
#define GRAYBLUE       	 0X5458 //灰藍色
//以上三色為PANEL的顏色 

#define LIGHTGREEN     	 0X841F //淺綠色
#define LGRAY 			 0XC618 //淺灰色(PANNEL),窗體背景色

#define LGRAYBLUE        0XA651 //淺灰藍色(中間層顏色)
#define LBBLUE           0X2B12 //淺棕藍色(選擇條目的反色)


#endif  

