/*******************************************************************************
  Main Source File

  Company:
    Microchip Technology Inc.

  File Name:
    main.c

  Summary:
    This file contains the "main" function for a project.

  Description:
    This file contains the "main" function for a project.  The
    "main" function calls the "SYS_Initialize" function to initialize the state
    machines of all modules in the system
 *******************************************************************************/

// *****************************************************************************
// *****************************************************************************
// Section: Included Files
// *****************************************************************************
// *****************************************************************************

#include <stddef.h>                     // Defines NULL
#include <stdbool.h>                    // Defines true
#include <stdlib.h>                     // Defines EXIT_FAILURE
#include <stdio.h>
#include <string.h>
#include "definitions.h"                // SYS function prototypes
#include "lcd.h"

char                    lcd_string[32];
volatile unsigned int   My_Counter = 0 ;
volatile unsigned int   User_Flag = 0 ;

// *****************************************************************************
// *****************************************************************************
// Section: Main Entry Point
// *****************************************************************************
// *****************************************************************************

void SYSTICK_EventHandler(uintptr_t context) {
            PB01_LED1_Toggle(); 
}

void TC0_ISR(TC_TIMER_STATUS status, uintptr_t context) {
    if (status & TC_INTFLAG_OVF_Msk) {
        My_Counter +=1;
        User_Flag = 1 ;
    }
}

int main ( void )
{
    /* Initialize all modules */
    SYS_Initialize ( NULL );
    
        TFT_LED_Set() ;   
        TC0_TimerCallbackRegister( TC0_ISR, (uintptr_t) NULL) ;
        TC0_TimerStart();   
        
            SYSTICK_TimerCallbackSet(&SYSTICK_EventHandler, (uintptr_t) NULL);
            SYSTICK_TimerStart();

             Lcd_Init();
             LCD_Clear(BLACK);
             
            showimage(1, 0, 0, 128, 160, 1);             

    while ( true )
    {
        /* Maintain state machines of all polled MPLAB Harmony modules. */
        SYS_Tasks ( );
        if (User_Flag != 0)
        {
                PB02_LED2_Toggle();
                User_Flag = 0 ;  
        }
        
        if (My_Counter == 50)
        {
            TFT_LED_Clear() ;
        }
        
        if (!PB00_SW3_Get())
        {
            TFT_LED_Set() ;
            My_Counter = 0 ;
        }
            
    }

    /* Execution should not come here during normal operation */

    return ( EXIT_FAILURE );
}


/*******************************************************************************
 End of File
*/